import { Logger } from "../shared/Logger";
import { Server } from "../Server";
import { IService } from "../Service";
import { IAuthProvider } from "../auth";
import { User } from "../realms";
export interface AuthServiceConfiguration {
    enableRuntimeConfiguration?: boolean;
    refreshTokenTtl?: number;
    userTokenTtl?: number;
    accessTokenTtl?: number;
}
export interface IAuthProviderConfig {
    type: string;
    name?: string;
    config?: any;
    forceCodeConfig?: boolean;
}
export declare class AuthService implements IService {
    logger: Logger;
    server: Server;
    private privateKey;
    private publicKey;
    private adminToken;
    private refreshTokenTtl;
    private userTokenTtl;
    private accessTokenTtl;
    private cleanupInterval;
    private adminRealm;
    private tokenRevocationRealm;
    private configurationRealm;
    private providers;
    private defaultProviders;
    private runtimeConfigurationEnabled;
    constructor(config?: AuthServiceConfiguration);
    addProvider(provider: IAuthProvider): void;
    setDefaultProviders(providers: IAuthProviderConfig[]): void;
    getUserByProviderId(provider: string, providerId: string): User;
    createOrUpdateUser(providerId: string, provider: string, isAdmin: boolean, metadata?: {
        [key: string]: string;
    }, userId?: string): Promise<User>;
    updateUserMetadata(user: User | string, metadata?: {
        [key: string]: string;
    }): void;
    private start;
    private stopping;
    private stop;
    private authenticate;
    private userToken;
    private accessToken;
    private revokeToken;
    private getUserById;
    private getUserByProviderIdApi;
    private createOrUpdateUserApi;
    private getProviders;
    private addOrUpdateProviderApi;
    private removeProviderApi;
    private updateProviderData;
    private updateProviderAccount;
    private deleteUser;
    private createProvider;
    private startProvider;
    private stopProvider;
    private pruneRevocationTokens;
    private readonly providerQueue;
    private hasPendingProviderOperations;
    private enqueueProviderOperation;
    private stopProviderQueue;
    private generateUniqueId;
    private requireAdminOrUserId;
    private requireRuntimeConfiguration;
    private deleteUserWithUserId;
    private static ensureRealmOfType;
}
